library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;
use IEEE.STD_LOGIC_TEXTIO.ALL;
use STD.TEXTIO.ALL;

entity keyb_model is
port (
	
	ps2_clk		: out std_logic;		--ps/2 clock signal from keyboard
	ps2_data	: out std_logic
);
end keyb_model;


architecture behavioral of keyb_model is

	signal clk : std_logic := '0';

	signal run_ps2_clk : boolean;

	constant ps2_clk_p : time := 30 us;	--real spec	
	--constant ps2_clk_p : time := 100 ns;		

begin

	clk <= not clk after ps2_clk_p/2;

	ps2_clk <= clk when run_ps2_clk = true else '1';	--only enable ps2_clk when sending data



	feed_keys: process 
		file key_file: text;
		variable key_line: line;
		variable key: integer;
		variable good_key: boolean;
		variable scan_code : std_logic_vector(7 downto 0);
		variable i : integer;
		variable even : std_logic;  		--for computing parity
		variable echo : line;
	begin
		ps2_data <= '1';
		run_ps2_clk <= false;
		
		--wait a bit before first key is pressed		
		wait for 2 us;		

        file_open(key_file,"key_file.txt",READ_MODE);
        
		while not endfile(key_file) loop
			readline(key_file,key_line);
			hread(key_line, scan_code, good=>good_key);		--reads hex value from file
			next when not good_key;		--skip if invalid value

			write(echo,string'("scan code: "));
			hwrite(echo,scan_code);
			writeline(output,echo);	--echo key value to console
						
			--synch clock with data
			wait until rising_edge(clk);
			wait for ps2_clk_p/4;
			--start bit
			ps2_data <= '0';
			--clock synch
			wait for ps2_clk_p/4;
			run_ps2_clk <= true;
			wait for ps2_clk_p*3/4;
			
			even := '0';
			--data bits
			for i in 7 downto 0 loop
				ps2_data <= scan_code(7-i);
				wait for ps2_clk_p;
				even := even xor scan_code(i);
			end loop;

			--odd parity bit
			ps2_data <= not even;
			wait for ps2_clk_p;

			--stop bit
			ps2_data <= '1';
			wait for ps2_clk_p;
	
			
			run_ps2_clk <= false;
			--wait for 5 us;
			wait for ps2_clk_p * 10;
		end loop;

		wait;		
	end process feed_keys;

end behavioral;
