-------------------------------------------------------------------------------
-- $Id$
-------------------------------------------------------------------------------
-- FIFO_Count.vhd
-------------------------------------------------------------------------------
--
--                  ****************************
--                  ** Copyright Xilinx, Inc. **
--                  ** All rights reserved.   **
--                  ****************************
--
-------------------------------------------------------------------------------
-- Filename:        FIFO_Count.vhd
--
-- Description:     
--                  
-- VHDL-Standard:   VHDL'93
-------------------------------------------------------------------------------
-- Structure:   
--              FIFO_Count.vhd
--
-------------------------------------------------------------------------------
-- Author:          goran
-- Revision:        $Revision$
-- Date:            $Date$
--
-- History:
--   goran  2002-02-08    First Version
--
-------------------------------------------------------------------------------
-- Naming Conventions:
--      active low signals:                     "*_n"
--      clock signals:                          "clk", "clk_div#", "clk_#x" 
--      reset signals:                          "rst", "rst_n" 
--      generics:                               "C_*" 
--      user defined types:                     "*_TYPE" 
--      state machine next state:               "*_ns" 
--      state machine current state:            "*_cs" 
--      combinatorial signals:                  "*_com" 
--      pipelined or register delay signals:    "*_d#" 
--      counter signals:                        "*cnt*"
--      clock enable signals:                   "*_ce" 
--      internal version of output port         "*_i"
--      device pins:                            "*_pin" 
--      ports:                                  - Names begin with Uppercase 
--      processes:                              "*_PROCESS" 
--      component instantiations:               "<ENTITY_>I_<#|FUNC>
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;

entity FIFO_Count is  
  port (
    Cnt_In  : in  std_logic_vector(3 downto 0);
    Cnt_Out : out std_logic_vector(3 downto 0)
    );
end entity FIFO_Count;

architecture IMP of FIFO_Count is
  
  subtype Cnt_Type is std_logic_vector(3 downto 0);
  
  function Count (Cnt : Cnt_Type) return Cnt_Type is
  begin  -- function Count
    if (Cnt = "0000") then
      return "0010";
    elsif (Cnt = "0010") then
      return "0011";
    elsif (Cnt = "0011") then
      return "0001";
    elsif (Cnt = "0001") then
      return "1001";
    elsif (Cnt = "1001") then
      return "1000";
    elsif (Cnt = "1000") then
      return "1010";
    elsif (Cnt = "1010") then
      return "1011";
    elsif (Cnt = "1011") then
      return "1111";
    elsif (Cnt = "1111") then
      return "1110";
    elsif (Cnt = "1110") then
      return "1100";
    elsif (Cnt = "1100") then
      return "1101";
    elsif (Cnt = "1101") then
      return "0101";
    elsif (Cnt = "0101") then
      return "0111";
    elsif (Cnt = "0111") then
      return "0110";
    elsif (Cnt = "0101") then
      return "0100";
--      elsif (Cnt = "0100") then
      else
        return "0000";
    end if;
  end function Count;

begin  -- architecture IMP

  Cnt_Out <= Count(Cnt_In);

end architecture IMP;
