-------------------------------------------------------------------------------
-- $Id$
-------------------------------------------------------------------------------
-- char_ram.vhdl
-------------------------------------------------------------------------------
--
--                  ****************************
--                  ** Copyright Xilinx, Inc. **
--                  ** All rights reserved.   **
--                  ****************************
--
-------------------------------------------------------------------------------
-- Filename:        char_ram.vhdl
--
-- Description:     
--                  
-- VHDL-Standard:   VHDL'93
-------------------------------------------------------------------------------
-- Structure:   
--              char_ram.vhdl
--
-------------------------------------------------------------------------------
-- Author:          goran
-- Revision:        $Revision$
-- Date:            $Date$
--
-- History:
--   rickb  2001-07-17    Verilog Version
--   goran  2002-01-18    VHDL Version
--
-------------------------------------------------------------------------------
-- Naming Conventions:
--      active low signals:                     "*_n"
--      clock signals:                          "clk", "clk_div#", "clk_#x" 
--      reset signals:                          "rst", "rst_n" 
--      generics:                               "C_*" 
--      user defined types:                     "*_TYPE" 
--      state machine next state:               "*_ns" 
--      state machine current state:            "*_cs" 
--      combinatorial signals:                  "*_com" 
--      pipelined or register delay signals:    "*_d#" 
--      counter signals:                        "*cnt*"
--      clock enable signals:                   "*_ce" 
--      internal version of output port         "*_i"
--      device pins:                            "*_pin" 
--      ports:                                  - Names begin with Uppercase 
--      processes:                              "*_PROCESS" 
--      component instantiations:               "<ENTITY_>I_<#|FUNC>
-------------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;

library unisim;
use unisim.all;
 
entity char_ram is
  port (
    -- OPB read and write port
    Clk           : in  std_logic;
    Address       : in  std_logic_vector(12 downto 0);
    Read_Data     : out std_logic_vector(7 downto 0);
    Write_Data    : in  std_logic_vector(7 downto 0);
    Write         : in  std_logic;
    -- Pixel read port
    Pixel_Clock   : in  std_logic;
    Pixel_Address : in  std_logic_vector(12 downto 0);
    Pixel_Read    : in  std_logic;
    Pixel_Data    : out std_logic_vector(7 downto 0)
    );

end entity char_ram;

architecture IMP of char_ram is
  component RAMB16_S2_S2
    port (
      -- Port A
      CLKA  : in  std_ulogic;
      ENA   : in  std_ulogic;
      WEA   : in  std_ulogic;
      SSRA  : in  std_ulogic;
      ADDRA : in  std_logic_vector (12 downto 0);
      DIA   : in  std_logic_vector (1 downto 0);
      DOA   : out std_logic_vector (1 downto 0);
      -- Port B
      CLKB  : in  std_ulogic;
      ENB   : in  std_ulogic;
      WEB   : in  std_ulogic;
      SSRB  : in  std_ulogic;
      ADDRB : in  std_logic_vector (12 downto 0);
      DIB   : in  std_logic_vector (1 downto 0);
      DOB   : out std_logic_vector (1 downto 0)
      ); 
  end component;

  attribute INIT_00 : string;
  attribute INIT_01 : string;
  attribute INIT_02 : string;
  attribute INIT_03 : string;
  attribute INIT_04 : string;
  attribute INIT_05 : string;
  attribute INIT_06 : string;
  attribute INIT_07 : string;
  attribute INIT_08 : string;
  attribute INIT_09 : string;
  attribute INIT_0A : string;
  attribute INIT_0B : string;
  attribute INIT_0C : string;
  attribute INIT_0D : string;
  attribute INIT_0E : string;
  attribute INIT_0F : string;
  attribute INIT_10 : string;
  attribute INIT_11 : string;
  attribute INIT_12 : string;
  attribute INIT_13 : string;
  attribute INIT_14 : string;
  attribute INIT_15 : string;
  attribute INIT_16 : string;
  attribute INIT_17 : string;
  attribute INIT_18 : string;
  attribute INIT_19 : string;
  attribute INIT_1A : string;
  attribute INIT_1B : string;
  attribute INIT_1C : string;
  attribute INIT_1D : string;
  attribute INIT_1E : string;
  attribute INIT_1F : string;
  attribute INIT_20 : string;
  attribute INIT_21 : string;
  attribute INIT_22 : string;
  attribute INIT_23 : string;
  attribute INIT_24 : string;
  attribute INIT_25 : string;
  attribute INIT_26 : string;
  attribute INIT_27 : string;
  attribute INIT_28 : string;
  attribute INIT_29 : string;
  attribute INIT_2A : string;
  attribute INIT_2B : string;
  attribute INIT_2C : string;
  attribute INIT_2D : string;
  attribute INIT_2E : string;
  attribute INIT_2F : string;
  attribute INIT_30 : string;
  attribute INIT_31 : string;
  attribute INIT_32 : string;
  attribute INIT_33 : string;
  attribute INIT_34 : string;
  attribute INIT_35 : string;
  attribute INIT_36 : string;
  attribute INIT_37 : string;
  attribute INIT_38 : string;
  attribute INIT_39 : string;
  attribute INIT_3A : string;
  attribute INIT_3B : string;
  attribute INIT_3C : string;
  attribute INIT_3D : string;
  attribute INIT_3E : string;
  attribute INIT_3F : string;

  attribute INIT_00 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_01 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_02 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_03 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_04 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_05 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_06 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_07 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_08 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_09 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0A of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0B of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0C of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0D of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0E of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0F of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_10 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_11 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_12 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_13 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_14 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_15 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_16 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_17 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_18 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_19 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1A of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1B of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1C of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1D of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1E of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1F of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_20 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_21 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_22 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_23 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_24 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_25 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_26 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_27 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_28 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_29 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2A of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2B of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2C of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2D of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2E of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2F of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_30 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_31 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_32 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_33 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_34 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_35 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_36 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_37 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_38 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_39 of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3A of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3B of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3C of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3D of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3E of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3F of RAM_BITS_1_0 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_00 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_01 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_02 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_03 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_04 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_05 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_06 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_07 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_08 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_09 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0A of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0B of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0C of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0D of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0E of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0F of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_10 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_11 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_12 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_13 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_14 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_15 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_16 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_17 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_18 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_19 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1A of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1B of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1C of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1D of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1E of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1F of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_20 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_21 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_22 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_23 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_24 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_25 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_26 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_27 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_28 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_29 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2A of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2B of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2C of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2D of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2E of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2F of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_30 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_31 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_32 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_33 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_34 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_35 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_36 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_37 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_38 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_39 of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3A of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3B of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3C of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3D of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3E of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3F of RAM_BITS_3_2 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_00 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_01 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_02 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_03 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_04 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_05 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_06 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_07 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_08 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_09 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_0A of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_0B of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_0C of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_0D of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_0E of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_0F of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";

  attribute INIT_10 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_11 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_12 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_13 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_14 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_15 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_16 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_17 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_18 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_19 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_1A of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_1B of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_1C of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_1D of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_1E of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_1F of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";

  attribute INIT_20 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_21 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_22 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_23 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_24 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_25 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_26 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_27 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_28 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_29 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_2A of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_2B of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_2C of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_2D of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_2E of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_2F of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";

  attribute INIT_30 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_31 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_32 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_33 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_34 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_35 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_36 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_37 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_38 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_39 of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_3A of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_3B of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_3C of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_3D of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_3E of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
  attribute INIT_3F of RAM_BITS_5_4 : label is "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";

  attribute INIT_00 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_01 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_02 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_03 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_04 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_05 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_06 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_07 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_08 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_09 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0A of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0B of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0C of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0D of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0E of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_0F of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_10 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_11 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_12 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_13 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_14 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_15 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_16 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_17 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_18 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_19 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1A of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1B of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1C of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1D of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1E of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_1F of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_20 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_21 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_22 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_23 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_24 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_25 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_26 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_27 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_28 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_29 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2A of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2B of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2C of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2D of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2E of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_2F of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  attribute INIT_30 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_31 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_32 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_33 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_34 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_35 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_36 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_37 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_38 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_39 of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3A of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3B of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3C of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3D of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3E of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";
  attribute INIT_3F of RAM_BITS_7_6 : label is "0000000000000000000000000000000000000000000000000000000000000000";

  signal null_2 : std_logic_vector(1 downto 0);
  
begin  -- architecture IMP

  null_2 <= (others => '0');

  RAM_BITS_1_0 : RAMB16_S2_S2
    port map (
      -- Processor read/write port
      CLKA  => Clk,                     -- [in  std_ulogic]
      ENA   => '1',                     -- [in  std_ulogic]
      WEA   => Write,                   -- [in  std_ulogic]
      SSRA  => '0',                     -- [in  std_ulogic]
      ADDRA => Address,                 -- [in  std_logic_vector (12 downto 0)]
      DIA   => Write_Data(1 downto 0),  -- [in  std_logic_vector (1 downto 0)]
      DOA   => Read_Data(1 downto 0),   -- [out std_logic_vector (1 downto 0)]
      -- Pixel read port
      CLKB  => Pixel_Clock,             -- [in  std_ulogic]
      ENB   => Pixel_Read,              -- [in  std_ulogic]
      WEB   => '0',                     -- [in  std_ulogic]
      SSRB  => '0',                     -- [in  std_ulogic]
      ADDRB => Pixel_Address,           -- [in  std_logic_vector (12 downto 0)]
      DIB   => null_2,                  -- [in  std_logic_vector (1 downto 0)]
      DOB   => Pixel_Data(1 downto 0));  -- [out std_logic_vector (1 downto 0)]

  RAM_BITS_3_2 : RAMB16_S2_S2
    port map (
      -- Processor read/write port
      CLKA  => Clk,                     -- [in  std_ulogic]
      ENA   => '1',                     -- [in  std_ulogic]
      WEA   => Write,                   -- [in  std_ulogic]
      SSRA  => '0',                     -- [in  std_ulogic]
      ADDRA => Address,                 -- [in  std_logic_vector (12 downto 0)]
      DIA   => Write_Data(3 downto 2),  -- [in  std_logic_vector (1 downto 0)]
      DOA   => Read_Data(3 downto 2),   -- [out std_logic_vector (1 downto 0)]
      -- Pixel read port
      CLKB  => Pixel_Clock,             -- [in  std_ulogic]
      ENB   => Pixel_Read,              -- [in  std_ulogic]
      WEB   => '0',                     -- [in  std_ulogic]
      SSRB  => '0',                     -- [in  std_ulogic]
      ADDRB => Pixel_Address,           -- [in  std_logic_vector (12 downto 0)]
      DIB   => null_2,                  -- [in  std_logic_vector (1 downto 0)]
      DOB   => Pixel_Data(3 downto 2));  -- [out std_logic_vector (1 downto 0)]

  RAM_BITS_5_4 : RAMB16_S2_S2
    port map (
      -- Processor read/write port
      CLKA  => Clk,                     -- [in  std_ulogic]
      ENA   => '1',                     -- [in  std_ulogic]
      WEA   => Write,                   -- [in  std_ulogic]
      SSRA  => '0',                     -- [in  std_ulogic]
      ADDRA => Address,                 -- [in  std_logic_vector (12 downto 0)]
      DIA   => Write_Data(5 downto 4),  -- [in  std_logic_vector (1 downto 0)]
      DOA   => Read_Data(5 downto 4),   -- [out std_logic_vector (1 downto 0)]
      -- Pixel read port
      CLKB  => Pixel_Clock,             -- [in  std_ulogic]
      ENB   => Pixel_Read,              -- [in  std_ulogic]
      WEB   => '0',                     -- [in  std_ulogic]
      SSRB  => '0',                     -- [in  std_ulogic]
      ADDRB => Pixel_Address,           -- [in  std_logic_vector (12 downto 0)]
      DIB   => null_2,                  -- [in  std_logic_vector (1 downto 0)]
      DOB   => Pixel_Data(5 downto 4));  -- [out std_logic_vector (1 downto 0)]

  RAM_BITS_7_6 : RAMB16_S2_S2
    port map (
      -- Processor read/write port
      CLKA  => Clk,                     -- [in  std_ulogic]
      ENA   => '1',                     -- [in  std_ulogic]
      WEA   => Write,                   -- [in  std_ulogic]
      SSRA  => '0',                     -- [in  std_ulogic]
      ADDRA => Address,                 -- [in  std_logic_vector (12 downto 0)]
      DIA   => Write_Data(7 downto 6),  -- [in  std_logic_vector (1 downto 0)]
      DOA   => Read_Data(7 downto 6),   -- [out std_logic_vector (1 downto 0)]
      -- Pixel read port
      CLKB  => Pixel_Clock,             -- [in  std_ulogic]
      ENB   => Pixel_Read,              -- [in  std_ulogic]
      WEB   => '0',                     -- [in  std_ulogic]
      SSRB  => '0',                     -- [in  std_ulogic]
      ADDRB => Pixel_Address,           -- [in  std_logic_vector (12 downto 0)]
      DIB   => null_2,                  -- [in  std_logic_vector (1 downto 0)]
      DOB   => Pixel_Data(7 downto 6));  -- [out std_logic_vector (1 downto 0)]

end architecture IMP;
