-------------------------------------------------------------------------------
-- $Id$
-------------------------------------------------------------------------------
-- color_pipe.vhd
-------------------------------------------------------------------------------
--
--                  ****************************
--                  ** Copyright Xilinx, Inc. **
--                  ** All rights reserved.   **
--                  ****************************
--
-------------------------------------------------------------------------------
-- Filename:        color_pipe.vhd
--
-- Description:     This module creates a pipeline delay for the character color data
--		    to synchronize the pixel data and the color data.
--                  
-- VHDL-Standard:   VHDL'93
-------------------------------------------------------------------------------
-- Structure:   
--              color_pipe.vhd
--
-------------------------------------------------------------------------------
-- Author:          goran
-- Revision:        $Revision$
-- Date:            $Date$
--
-- History:
--   rickb  2001-07-17    Verilog Version
--   goran  2002-01-18    VHDL Version
--
-------------------------------------------------------------------------------
-- Naming Conventions:
--      active low signals:                     "*_n"
--      clock signals:                          "clk", "clk_div#", "clk_#x" 
--      reset signals:                          "rst", "rst_n" 
--      generics:                               "C_*" 
--      user defined types:                     "*_TYPE" 
--      state machine next state:               "*_ns" 
--      state machine current state:            "*_cs" 
--      combinatorial signals:                  "*_com" 
--      pipelined or register delay signals:    "*_d#" 
--      counter signals:                        "*cnt*"
--      clock enable signals:                   "*_ce" 
--      internal version of output port         "*_i"
--      device pins:                            "*_pin" 
--      ports:                                  - Names begin with Uppercase 
--      processes:                              "*_PROCESS" 
--      component instantiations:               "<ENTITY_>I_<#|FUNC>
-------------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;

entity color_pipe is

  port (
    Pixel_Clock        : in  std_logic;
    Reset              : in  std_logic;
    Color_Ram_Data     : in  std_logic_vector(3 downto 0);
    Aligned_Color_Data : out std_logic_vector(3 downto 0)
    );

end entity color_pipe;

architecture IMP of color_pipe is

  signal color_pipe0 : std_logic_vector(Color_Ram_Data'range);
  signal color_pipe1 : std_logic_vector(Color_Ram_Data'range);
begin  -- architecture IMP

  Aligning : process (Pixel_Clock, Reset) is
  begin  -- process Aligning
    if Reset = '1' then                 -- asynchronous reset (active high)
      color_pipe0        <= (others => '0');
      color_pipe1        <= (others => '0');
      Aligned_Color_Data <= (others => '0');
    elsif Pixel_Clock'event and Pixel_Clock = '1' then  -- rising clock edge
      color_pipe0 <= Color_Ram_Data;
      color_pipe1 <= color_pipe0;
      Aligned_Color_Data <= color_pipe1;
    end if;
  end process Aligning;

end architecture IMP;
