LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
USE ieee.std_logic_unsigned.all;
USE ieee.numeric_std.ALL;

library opb_keyboard_v1_00_a;
use opb_keyboard_v1_00_a.all;


ENTITY toplevel_tb_vhd IS
END toplevel_tb_vhd;

ARCHITECTURE behavior OF toplevel_tb_vhd IS 

	-- Component Declaration for the Unit Under Test (UUT)
	COMPONENT user_logic
	PORT(
		ps2_clk 					: in std_logic;
		ps2_data 					: in std_logic;
		Bus2IP_Clk                     : in  std_logic;
		Bus2IP_Reset                   : in  std_logic;
		Bus2IP_Data                    : in  std_logic_vector(0 to 32-1);
		Bus2IP_BE                      : in  std_logic_vector(0 to 32/8-1);
		Bus2IP_RdCE                    : in  std_logic_vector(0 to 4-1);
		Bus2IP_WrCE                    : in  std_logic_vector(0 to 4-1);
		IP2Bus_Data                    : out std_logic_vector(0 to 32-1);
		IP2Bus_Ack                     : out std_logic;
		IP2Bus_Retry                   : out std_logic;
		IP2Bus_Error                   : out std_logic;
		IP2Bus_ToutSup                 : out std_logic
	);
	END COMPONENT;


	component keyb_model
	port (
		ps2_clk		: out std_logic;		--ps/2 clock signal from keyboard
		ps2_data	: out std_logic
	);
	end component;


	--Inputs
	SIGNAL ps2_clk :  std_logic := '0';
	SIGNAL ps2_data :  std_logic := '0';

	signal Bus2IP_Clk                     : std_logic := '0';
	signal Bus2IP_Reset                   : std_logic;
	signal Bus2IP_Data                    : std_logic_vector(0 to 32-1);
	signal Bus2IP_BE                      : std_logic_vector(0 to 32/8-1);
	signal Bus2IP_RdCE                    : std_logic_vector(0 to 4-1);
	signal Bus2IP_WrCE                    : std_logic_vector(0 to 4-1);
	signal IP2Bus_Data                    : std_logic_vector(0 to 32-1);
	signal IP2Bus_Ack                     : std_logic;
	signal IP2Bus_Retry                   : std_logic;
	signal IP2Bus_Error                   : std_logic;
	signal IP2Bus_ToutSup                 : std_logic;

	CONSTANT clk_p : time := 20 ns;

BEGIN

	-- Instantiate the Unit Under Test (UUT)
	uut: user_logic PORT MAP(
		ps2_clk => ps2_clk,
		ps2_data => ps2_data,
		Bus2IP_Clk => Bus2IP_Clk,
		Bus2IP_Reset => Bus2IP_Reset,                                  
		Bus2IP_Data => Bus2IP_Data, 
		Bus2IP_BE => Bus2IP_BE, 
		Bus2IP_RdCE => Bus2IP_RdCE, 
		Bus2IP_WrCE => Bus2IP_WrCE,
		IP2Bus_Data => IP2Bus_Data,
		IP2Bus_Ack => IP2Bus_Ack,
		IP2Bus_Retry => IP2Bus_Retry,
		IP2Bus_Error => IP2Bus_Error,
		IP2Bus_ToutSup => IP2Bus_ToutSup
	);

	keybmodel: keyb_model port map (
		ps2_clk		=> ps2_clk,
		ps2_data	=> ps2_data
	);


	bus2ip_clk <= not bus2ip_clk after clk_p/2;

	tb : PROCESS
	
		procedure read_reg(reg: in std_logic_vector(0 to 3)) is 
		begin
			Bus2IP_RdCE <= reg; 
			wait for clk_p;
			Bus2IP_RdCE <= "0000"; 
		end read_reg;
		
		procedure write_reg(reg: in std_logic_vector(0 to 3); data: in std_logic_vector(0 to 31)) is
		begin
			Bus2IP_Data <= data; 
			Bus2IP_WrCE <= reg; 
			wait for clk_p;
			Bus2IP_WrCE <= "0000"; 
			Bus2IP_Data <= x"00000000"; 
		end write_reg;		

	BEGIN
		Bus2IP_Data <= x"00000000"; 
		Bus2IP_BE  <= "0000";
		Bus2IP_RdCE <= "0000"; 
		Bus2IP_WrCE <= "0000"; 

		bus2ip_reset <= '1';
		wait for 4*clk_p;
		bus2ip_reset <= '0';

		--sjekk om available
		wait for 250 us;
		read_reg("0100");
				
		--sjekk om available
		wait for 250 us;
		read_reg("0100");
			
		--les data
		wait for 20*clk_p;
		read_reg("1000");
		
		--skriv til read
		wait for 20*clk_p;
		write_reg("0010",x"00000001");

		--sjekk om available
		wait for 20*clk_p;
		read_reg("0100");


		wait; -- will wait forever
	END PROCESS;

END;
